@@ -318,6 +318,17 @@ By default, it will include all existing files in the top-level source directory
             }
           ]
         }
+      },
+      'upstream-metadata',
+      {
+        'config_class_name' => 'Dpkg::Upstream::Metadata',
+        'description' => 'The upstream metadata file is meant to contain machine-readable metadata about the upstream project, its community and processes.
+
+Information in this file should not be specific to Debian, and be relevant for other distributions as well.
+
+',
+        'summary' => 'Upstream Metadata Specification',
+        'type' => 'node'
       }
     ],
     'license' => 'LGPL2',
