@@ -90,9 +90,75 @@ A package may specify an architecture wildcard. Architecture wildcards are in th
       },
       'Essential',
       {
+        'description' => 'The package is an essential package as defined by Debian Policy. The following
+rules apply to the package:
+
+'.'=over
+
+'.'=item *
+
+Essential packages are considered essential for the system to work.
+The packaging system (APT and dpkg) will warn and refuse to uninstall
+them without some very insistent force options.
+
+'.'=item *
+
+Other packages are not required to declare explicit dependencies on
+essential packages as a side-effect of the above except as needed to
+ensure that the given essential package is upgraded to a given minimum
+version.
+
+'.'=item *
+
+Once installed, essential packages must function at all times no
+matter where dpkg is in its installation or upgrade process. During
+bootstrapping or installation, this requirement is relaxed.
+
+'.'=back
+
+Note that if you are looking for a way to prevent accidental uninstallation, please consider using C<Protected: yes> instead.
+',
+        'summary' => 'The package is essential as defined by Debian Policy',
         'type' => 'leaf',
         'value_type' => 'boolean'
       },
+      'XB-Important',
+      {
+        'description' => 'This is the prototype field that led to `Protected`, which should be used instead.
+
+It makes `apt` (but not `dpkg`) require extra confirmation before removing the package.',
+        'status' => 'deprecated',
+        'summary' => 'Obsolete and incomplete variant of the Protected field',
+        'type' => 'leaf',
+        'upstream_default' => 'no',
+        'value_type' => 'boolean'
+      },
+      'Protected',
+      {
+        'description' => 'Declare this package as a system critical package. When the field is set to C<yes>, both C<apt>
+and C<dpkg> will assume that removing the package B<may> break the system. As a consequence,
+they will require extra confirmation (or "force" options) before removing the package.
+This field basically provides "uninstall" protection similar to that of C<Essential> packages
+without the other benefits and requirements that come with C<Essential> packages. In a Debian
+context, this field is generally applicable to packages like bootloaders, kernels, and other
+packages that might be necessary for booting the system.
+',
+        'help' => {
+          'no' => 'The package is a regular package.  This is the default and recommended.',
+          'yes' => 'The package is protected and attempts to uninstall it will cause strong warnings to the user that they might be breaking the system.'
+        },
+        'migrate_from' => {
+          'formula' => '$xbi',
+          'undef_is' => '0',
+          'variables' => {
+            'xbi' => '- XB-Important'
+          }
+        },
+        'summary' => 'Mark as Protected (uninstall protection)',
+        'type' => 'leaf',
+        'upstream_default' => 'no',
+        'value_type' => 'boolean'
+      },
       'Depends',
       {
         'cargo' => {
@@ -343,6 +409,17 @@ supported by the library',
           ]
         }
       },
+      'X-DhRuby-Root',
+      {
+        'description' => 'Used by C<dh_ruby> to request "multi-binary" layout and where the root for the given
+package is.
+
+Please refer to L<dh_ruby|https://manpages.debian.org/dh_ruby> documentation for more details.
+',
+        'summary' => 'For multi-binary layout with the dh_ruby tool',
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
       'Build-Profiles',
       {
         'description' => 'Build-Profiles specifies the condition for which that binary package does or does not build. 
@@ -357,6 +434,85 @@ See L<https://wiki.debian.org/BuildProfileSpec#The_Build-Profiles_field> for mor
         'match' => '^<!?[a-z0-9.-]+(?:\\s+!?[a-z0-9.-]+)*>(?:\\s+<!?[a-z0-9.-]+(?:\\s+!?[a-z0-9.-]+)*>)*$',
         'type' => 'leaf',
         'value_type' => 'uniline'
+      },
+      'XB-Installer-Menu-Item',
+      {
+        'description' => '=pod
+
+This field is only relevant for C<udeb> packages (debian-installer).
+
+The field is used to declare where in the installer menu this package\'s menu item should
+be placed (assuming it has any menu item). For packages targeting the Debian archive,
+any new package should have its menu item number aligned with the debian-installer team
+before upload.
+
+A menu item is 4-5 digits (In the range C<< 1000 <= X <= 99999 >>). In rare cases, the menu
+item can be architecture dependent. For architecture dependent menu item values, use a
+custom substvar.
+
+See L<https://d-i.debian.org/doc/internals/apa.html> for the full list of menu item ranges
+and for how to request a number.
+',
+        'level' => 'hidden',
+        'summary' => 'Package\'s order in the debian-installer menu (udeb-only)',
+        'type' => 'leaf',
+        'value_type' => 'uniline',
+        'warp' => {
+          'follow' => {
+            'pkg_type' => '- Package-Type'
+          },
+          'rules' => [
+            '$pkg_type eq "udeb"',
+            {
+              'level' => 'normal'
+            }
+          ]
+        }
+      },
+      'X-DH-Build-For-Type',
+      {
+        'choice' => [
+          'host',
+          'target'
+        ],
+        'description' => 'B<Special-purpose only>. B<This field is a special purpose field and is rarely needed.>
+B<Leave it out unless you know you need it or someone told you to use it.>
+
+This field is used when building a cross-compiling C-compiler (or similar cases).  Some packages need
+to be built for the target (DEB_B<TARGET>_ARCH) rather than the host (DEB_B<HOST>_ARCH) architecture.
+',
+        'help' => {
+          'host' => 'The package should be compiled for C<DEB_HOST_ARCH>, which is the default behavior.',
+          'target' => 'The package should be compiled for C<DEB_TARGET_ARCH>.
+
+For steps that look at the values from C<dpkg-architecture> B<and> that are specific to this
+package, the C<DEB_TARGET_> variants are used instead of the C<DEB_HOST_> variants. In C<debhelper>,
+this usually affects C<dh_makeshlibs> and C<dh_shlibdeps>. In C<debputy>, it affects the parts of the
+manifest that are run in a package specific context, such as the parts beneath the C<packages>
+root-level keyword.
+
+This value is exceedingly rare to the point where if you do not know you need it,
+then you are not looking for this value (or the field in general).
+'
+        },
+        'summary' => 'For cross-compiling cross-compilers',
+        'type' => 'leaf',
+        'upstream_default' => 'host',
+        'value_type' => 'enum'
+      },
+      'X-Time64-Compat',
+      {
+        'description' => 'Special purpose field related to the 64-bit time transition.
+
+It is used to inform packaging helpers what the original (non-transitioned) package name
+was when the auto-detection is inadequate. The non-transitioned package name is then
+conditionally provided in the C<${{t64:Provides}}> substitution variable.
+
+The field only works for architecture dependent packages.
+',
+        'summary' => '(Special purpose) Compat name for time64_t transition',
+        'type' => 'leaf',
+        'value_type' => 'uniline'
       }
     ],
     'license' => 'LGPL2',
