@@ -48,6 +48,45 @@ For details, see L<section 5.7 of Debian policy|https://www.debian.org/doc/debia
         'type' => 'leaf',
         'value_type' => 'integer'
       },
+      'X-Style',
+      {
+        'description' => 'Uncompromising file formatting of Debian packaging files
+
+By using it, you agree to cede control over minutiae of hand-formatting. In return, the formatter gives you speed, determinism, and freedom from style discussions about formatting.
+
+The C<black> style is inspired by the C<black> Python code formatter. As with C<black>, the style will evolve over time.
+',
+        'summary' => 'Uncompromising file formatting of Debian packaging files',
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'Standards-Version',
+      {
+        'class' => 'Config::Model::Dpkg::Control::Source::StandardVersion',
+        'description' => 'This field indicates the Debian policy version number this package complies to.
+
+Before updating this field, please read L<upgrading-checklist|https://www.debian.org/doc/debian-policy/upgrading-checklist.html>
+to know what changes came with a new policy version number and apply the required changes (if any) to your package.',
+        'mandatory' => '1',
+        'match' => '^\\d+\\.\\d+\\.\\d+(\\.\\d+)?$',
+        'summary' => 'Debian policy version number this package complies to',
+        'type' => 'leaf',
+        'value_type' => 'uniline',
+        'warn_if' => {
+          'current' => {
+            'code' => '$self->compare_with_last_version($_) == -1;',
+            'fix' => '$_ = $self->_fetch_std; # restore default value',
+            'msg' => 'Current standards version is \'$std_value\'. Please read https://www.debian.org/doc/debian-policy/upgrading-checklist.html for the changes that may be needed on your package
+to upgrade it from standard version \'$_\' to \'$std_value\'.
+'
+          },
+          'old_lintian' => {
+            'code' => '$self->compare_with_last_version($_) == 1;',
+            'msg' => 'Current standards version \'$_\' is newer than lintian version ($std_value). Please check your system
+'
+          }
+        }
+      },
       'Maintainer',
       {
         'compute' => {
@@ -81,33 +120,6 @@ a program using this field as an address must check for this and correct the pro
         },
         'type' => 'list'
       },
-      'Standards-Version',
-      {
-        'class' => 'Config::Model::Dpkg::Control::Source::StandardVersion',
-        'description' => 'This field indicates the Debian policy version number this package complies to.
-
-Before updating this field, please read L<upgrading-checklist|https://www.debian.org/doc/debian-policy/upgrading-checklist.html>
-to know what changes came with a new policy version number and apply the required changes (if any) to your package.',
-        'mandatory' => '1',
-        'match' => '^\\d+\\.\\d+\\.\\d+(\\.\\d+)?$',
-        'summary' => 'Debian policy version number this package complies to',
-        'type' => 'leaf',
-        'value_type' => 'uniline',
-        'warn_if' => {
-          'current' => {
-            'code' => '$self->compare_with_last_version($_) == -1;',
-            'fix' => '$_ = $self->_fetch_std; # restore default value',
-            'msg' => 'Current standards version is \'$std_value\'. Please read https://www.debian.org/doc/debian-policy/upgrading-checklist.html for the changes that may be needed on your package
-to upgrade it from standard version \'$_\' to \'$std_value\'.
-'
-          },
-          'old_lintian' => {
-            'code' => '$self->compare_with_last_version($_) == 1;',
-            'msg' => 'Current standards version \'$_\' is newer than lintian version ($std_value). Please check your system
-'
-          }
-        }
-      },
       'Section',
       {
         'default' => 'misc',
@@ -235,7 +247,6 @@ in Debian developer reference.',
           'optional',
           'extra'
         ],
-        'default' => 'optional',
         'help' => {
           'extra' => 'This contains all packages that conflict with others with required, important, standard or optional priorities, or are only likely to be useful
 if you already know what they are or have specialized requirements (such as packages containing only detached debugging symbols).',
@@ -252,6 +263,7 @@ Systems with only the required packages are probably unusable, but they do have
 select anything else. It doesn\'t include many large applications. '
         },
         'type' => 'leaf',
+        'upstream_default' => 'optional',
         'value_type' => 'enum',
         'warp' => {
           'follow' => {
@@ -267,6 +279,14 @@ select anything else. It doesn\'t include many large applications. '
           ]
         }
       },
+      'Build-Driver',
+      {
+        'description' => 'The name of the build driver that dpkg (`dpkg-buildpackage`) will use for assembling the package.',
+        'summary' => 'Which build-driver implementation dpkg should use for the package build',
+        'type' => 'leaf',
+        'upstream_default' => 'debian-rules',
+        'value_type' => 'uniline'
+      },
       'Build-Depends',
       {
         'cargo' => {
@@ -698,6 +718,24 @@ For more information see the "Debian Maintainer" page at the Debian Wiki - https
         'type' => 'leaf',
         'value_type' => 'uniline'
       },
+      'Bugs',
+      {
+        'description' => 'Provide a custom bug tracker URL
+
+This field is *not* used by packages uploaded to Debian or most derivatives as the distro tooling has a default bugtracker built in. It is primarily useful for third-party provided packages so that bug reporting tooling can redirect the user to their bug tracker.',
+        'summary' => 'Custom bugtracker URL (for third-party packages)',
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'Origin',
+      {
+        'description' => 'Declare the origin of the package.
+
+This field is *not* used by packages uploaded to Debian or most derivatives as the origin would be the distribution. It is primarily useful for third-party provided packages as some tools will detect this field and change behavior, for instance by informing the user that the package is a third-party package.',
+        'summary' => 'Custom origin (for third-party packages)',
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
       'Rules-Requires-Root',
       {
         'description' => 'Depending on the value of the Rules-Requires-Root field, the package builder (e.g. dpkg-buildpackage) may run the debian/rules target as an unprivileged user and provide a gain root command.
@@ -721,6 +759,54 @@ This is how every tool behaved before this field was defined.',
           }
         }
       },
+      'X-DH-Compat',
+      {
+        'description' => '=pod
+
+The C<X-DH-Compat> field is accepted by C<debhelper> as a way to declare the "debhelper compat level".
+Though, whenever possible, it is better to add C<debhelper-compat (= N)> to C<Build-Depends> as a way
+to declare the debhelper compat level.
+
+This field does B<not> count as a build-dependency, so the package will still need an explicit
+build-dependency on C<debhelper> on top of this field. As of C<debhelper compat> level 14, this is
+the only supported way to request a C<debhelper compat> level that is not yet stable.
+
+Example:
+
+    Source: foo
+    Build-Depends: debhelper (>= 13.26~)
+    # Use the experimental compat 14
+    X-DH-Compat: 14
+    # ...
+
+This field replaces the C<debian/compat> file that was the prior way of declaring unstable
+and experimental C<debhelper compat> levels.
+',
+        'summary' => 'Declare debhelper compat level (used for experimental compat levels)',
+        'type' => 'leaf',
+        'value_type' => 'uniline'
+      },
+      'X-Cargo-Crate',
+      {
+        'description' => 'This fields contains the name of the Rust cargo crate, which is packaged in this source package.
+
+It is used by Debian\'s Rust tooling to reliably identify the crate when it needs it. The source package name is not always sufficient for this purpose. As an example, the package name for the `utf-8` crate can both be read as `utf` with a major version of `8` or a as the crate name `utf-8`. This field is used to avoid the ambiguity. It is recommended to always include it for Rust packages.',
+        'summary' => 'Name of the Rust cargo crate packaged in this source package',
+        'type' => 'leaf',
+        'value_type' => 'uniline',
+        'warp' => {
+          'follow' => {
+            'maintainer' => '- Maintainer',
+            'source' => '- Source'
+          },
+          'rules' => [
+            '$maintainer =~ m!Debian Ruby!i or $source =~ /^ruby/',
+            {
+              'level' => 'normal'
+            }
+          ]
+        }
+      },
       'XS-Python-Version',
       {
         'status' => 'deprecated',
@@ -787,6 +873,51 @@ supported by the library',
             }
           ]
         }
+      },
+      'Synopsis',
+      {
+        'description' => '=head1 NAME
+
+This field contains a human-readable synopsis of the package. However,
+it is not used directly.  Binary packages can reference it via the
+C<${{source:Synopsis}}> substvars. Without any of these substvars, the
+C<Synopsis> (part of the C<Description> field) of the C<Source> stanza
+remains unused.  The B<Synopsis> is a short "noun-phrase" intended to provide a
+one-line summary of a package.
+
+The B<Synopsis> is usually displayed in cases where there is limited space such as when reviewing
+the search results from C<apt search foo>.  It is often a good idea to imagine that the B<Synopsis>
+part is inserted into a sentence like "The package provides {{Synopsis-goes-here}}".
+
+Please see L<control field doc|https://www.debian.org/doc/debian-policy/ch-controlfields.html#description>
+for more details about the description field and suggestions for how to write it.
+',
+        'summary' => 'Common base synopsis for all packages via substvar',
+        'type' => 'leaf',
+        'value_type' => 'string'
+      },
+      'Description',
+      {
+        'description' => '=head1 NAME
+
+This field contains a human-readable description of the
+package. However, it is not used directly.  Binary packages can
+reference parts it via the C<${{source:Extended-Description}}>
+substvars. Without this substvars, the C<Description> field of the
+C<Source> stanza remains unused.
+
+The B<Extended Description> is a standalone description that should
+describe what the package does and how it relates to the rest of the
+system (in terms of, for example, which subsystem it is which part
+of).
+
+Please see
+L<control field doc|https://www.debian.org/doc/debian-policy/ch-controlfields.html#description>
+for more details about the description field and suggestions for how to write it.
+',
+        'summary' => 'Common base description for all packages via substvar',
+        'type' => 'leaf',
+        'value_type' => 'string'
       }
     ],
     'license' => 'LGPL2',
