@@ -1,4 +1,7 @@
-[
+use strict;
+use warnings;
+
+return [
   {
     'element' => [
       'preinst',
@@ -34,9 +37,9 @@
     'rw_config' => {
       'auto_create' => '1',
       'auto_delete' => '1',
-      'backend' => 'PlainFile',
+      'backend' => 'Dpkg::DebHelperFile',
       'config_dir' => 'debian',
-      'file' => '&index(-).&element',
+      'file' => '&element',
       'file_mode' => 'a+x'
     }
   }
