@@ -120,6 +120,12 @@ This field can specify a list of abstract class names such as "desktop" or "grap
 This is purely an informational field for autopkgtest itself and will be ignored.',
         'type' => 'leaf',
         'value_type' => 'uniline'
+      },
+      'Architecture',
+      {
+        'description' => 'When package tests are only supported on a limited set of architectures, or are known to not work on a particular (set of) architecture(s), this field can be used to define the supported architectures. The autopkgtest will be skipped when the architecture of the testbed doesn\'t match the content of this field. The format is the same as in (Build-)Depends, with the understanding that C<all> is not allowed, and C<any> means that the test will be run on every architecture, which is the default when not specifying this field at all.',
+        'type' => 'leaf',
+        'value_type' => 'string'
       }
     ],
     'gist' => '{Tests:0}{Test-Command}',
