@@ -415,12 +415,16 @@ my $__extract_rakudoc_info = sub ($file, $grant, $current_dir) {
 
 my $__extract_dist_ini_info = sub ($file, $grant, $current_dir) {
     my $dist_ini = $current_dir->child($file);
+    my $cfg;
 
     if ($dist_ini->is_file) {
-        my $cfg = Config::IniFiles->new(
+        $cfg = Config::IniFiles->new(
             -file => $dist_ini->stringify,
             -fallback => 'top',
         );
+    }
+
+    if (defined $cfg) {
         $grant->license($cfg->val(qw/top license/)) if $cfg->exists(qw/top license/);
 
         if ($cfg->exists(qw/top copyright_holder/) or $cfg->exists(qw/top copyright_year/)) {
