@@ -60,6 +60,8 @@ my @tests = (
             'source Build-Depends-Indep:5', "libpath-class-perl",
             'source Build-Depends-Indep:6', "libmodule-build-perl (>= 0.360000)", # fixed
             'source Build-Depends-Indep:7', "udev [linux-any] | makedev [linux-any]",
+            'source Synopsis' => "foo synopsis",
+            'source Description' => "not so long foo description",
             'source X-Comment' => qr/Debian #810023/,
             'source Priority' => 'optional',
             'binary:libdist-zilla-plugins-cjm-perl X-Comment' => qr/Debian #810023/,
@@ -79,8 +81,8 @@ my @tests = (
         apply_fix => 1,
         file_contents_like => {
             'debian/control' => [
-                # check that write order is tweaked for Standards-Version
-                qr!Standards-Version: [\d.]+\nVcs-Browser!
+                # check that accepted fields are in sable alphabetical order
+                qr!X-t1: foo\nX-t2: foo\nX-t3: foo\nX-t4: foo\n!,
             ]
         },
         file_contents_unlike => {
@@ -93,14 +95,38 @@ my @tests = (
     {
 
         # t1
-        check => { 'binary:seaview Recommends:0', 'clustalw', },
+        check => {
+            'binary:seaview Recommends:0', 'clustalw',
+            'source Description' => "",
+            'source Synopsis' => "oops, no long description"
+        },
         apply_fix => 1,
-        load => 'binary:seaview Synopsis="multiplatform interface for sequence alignment"',
+        # remove Priority field
+        # see https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=1111391
+        load => 'source Priority~ - '
+        . 'binary:seaview Synopsis="multiplatform interface for sequence alignment"',
+        file_contents_unlike => {
+            'debian/control' => [
+                # check that Priority was removed from debian/control
+                qr!Priority: optional!,
+            ],
+        },
+        file_contents_like => {
+            'debian/control' => [
+                # check output style of lists is like wrap-and-sort -asr
+                # see https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=849498
+                qr!Depends:\n \$\{shlibs:Depends\},\n \$\{misc:Depends\},\nRecommends:\n !
+            ],
+        },
     },
     {
 
         # t2
         check => {
+            'source Synopsis' => "",
+            'source Description' => "oops, no synopsis",
+            # test migration from XB-Important to Protected
+            'binary:x11-common Protected' => 1,
             'binary:xserver-xorg-video-all Architecture' => 'any',
             'binary:xserver-xorg-video-all Depends:0'    => '${F:XServer-Xorg-Video-Depends}',
             'binary:xserver-xorg-video-all Depends:1'    => '${misc:Depends}',
