@@ -88,6 +88,9 @@ my @tests = (
             'package-scripts:./amd64 preinst' => qr/dummy preinst script for amd64/,
             'examples:t0 content:0' => 'examples/',
             'install:t0.docs content:0' => 'README.*',
+            'upstream-metadata FAQ' => 'http://www.netlib.org/lapack/faq.html',
+            'upstream-metadata Reference:0 Title' => "LAPACK Users' Guide",
+            'upstream-metadata Reference:0 Author' => qr/Sorensen/,
         },
         log4perl_load_warnings => [[
             User =>  map {(warn => $_)} qr/source Standards-Version/, qr/compat/, (qr/debhelper/) x 2 , qr/Dual dependency/
@@ -151,6 +154,9 @@ my @tests = (
             # copyright from files or existing debian/copyright are now normalised
             'copyright Files:pan/general/sorted-vector.h Copyright' => '2002, Martin Holzherr (holzherr@infobrain.com).',
 
+            # comment is now propagated from fill.copyright.blanks
+            'copyright Files:"pan/gui/*" Comment' => 'some comment about gui',
+
             # no space after comma because data comes from fix.scanned.copyright
             'copyright Files:pan/general/map-vector.h Copyright' => "2001,Andrei Alexandrescu",
             'copyright Files:pan/general/map-vector.h License short_name' => 'MIT',
